@@ -5,12 +5,12 @@ import { Widget } from '@lumino/widgets';
 import { FrontmatterBlock } from '@myst-theme/frontmatter';
 import { renderers } from './renderers';
 import { PageFrontmatter } from 'myst-frontmatter';
-import { References, GenericParent } from 'myst-common';
+import { GenericParent, References } from 'myst-common';
 import {
-  Theme,
-  ThemeProvider,
   ReferencesProvider,
-  TabStateProvider
+  TabStateProvider,
+  Theme,
+  ThemeProvider
 } from '@myst-theme/providers';
 import { render } from 'react-dom';
 import { useParse } from 'myst-to-react';
@@ -22,6 +22,8 @@ import { selectAll } from 'unist-util-select';
 import { PromiseDelegate } from '@lumino/coreutils';
 import { JupyterCellProvider } from './JupyterCellProvider';
 
+import { ObservableValue } from '@jupyterlab/observables';
+
 export class MySTMarkdownCell
   extends MarkdownCell
   implements IMySTMarkdownCell
@@ -34,6 +36,14 @@ export class MySTMarkdownCell
     node?: HTMLDivElement;
   } = {};
 
+  constructor(options: MarkdownCell.IOptions) {
+    super(options);
+
+    // Listen for changes to the cell trust
+    const trusted = this.model.modelDB.get('trusted') as ObservableValue;
+    trusted.changed.connect(this.mystRender, this);
+  }
+
   renderInput(_: Widget): void {
     if (!this.myst || !this.myst.node) {
       // Create the node if it does not exist
@@ -47,6 +57,7 @@ export class MySTMarkdownCell
     const parseComplete = parseContent(notebook);
     const widget = new Widget({ node: this.myst.node });
     widget.addClass('myst');
+    widget.addClass('jp-MarkdownOutput');
     this.addClass('jp-MySTMarkdownCell');
     this.inputArea.renderInput(widget);
     if (parseComplete) {
