@@ -3,11 +3,13 @@ import { DEFAULT_RENDERERS } from 'myst-to-react';
 import { MermaidNodeRenderer } from '@myst-theme/diagrams';
 import { NodeRenderer } from '@myst-theme/providers';
 import { InlineRenderer } from './inlineExpression';
+import { listItem } from './taskItem';
 
 export const renderers: Record<string, NodeRenderer> = {
   ...DEFAULT_RENDERERS,
   mermaid: MermaidNodeRenderer,
   inlineExpression: (node, children) => {
     return <InlineRenderer value={node.value} />;
-  }
+  },
+  listItem
 };
